@@ -25,7 +25,7 @@ class TwitterRestPager(object):
 
         :param wait: Integer number (default=5) of seconds wait between requests.
                      Depending on the resource, appropriate values are 5 or 60 seconds.
-        :param new_tweets: Boolean determining the search direction
+        :param new_tweets: Boolean determining the search direction.
                            False (default) retrieves old results.
                            True retrieves current results.
 
@@ -35,8 +35,8 @@ class TwitterRestPager(object):
         while True:
             # get one page of results
             start = time.time()
-            req = self.api.request(self.resource, self.params)
-            it = req.get_iterator()
+            r = self.api.request(self.resource, self.params)
+            it = r.get_iterator()
             if new_tweets:
                 it = reversed(list(it))
 
@@ -47,15 +47,19 @@ class TwitterRestPager(object):
                     id = item['id']
                 yield item
 
+			# bail when no more older results
+            if id is None and not new_tweets:
+            	break
+
             # sleep before getting another page of results
             elapsed = time.time() - start
             pause = wait - elapsed if elapsed < wait else 0
             time.sleep(pause)
 
-            # use the first or last tweet id to limit (depending on the newer/older direction)
-            # the next request
+            # use the first id to limit the next batch of newer tweets, or
+            # use the last id to limit the next batch of older tweets
             if id is None:
-                continue
+            	continue
             elif new_tweets:
                 self.params['since_id'] = str(id)
             else:
